@@ -1,7 +1,7 @@
 /*
 ******************************************************************************
 *
-*   Copyright (C) 1997-2010, International Business Machines
+*   Copyright (C) 1997-2011, International Business Machines
 *   Corporation and others.  All Rights Reserved.
 *
 ******************************************************************************
@@ -35,12 +35,16 @@
 
 /**
  * Determine wheter to enable auto cleanup of libraries. 
- * @draft ICU 4.4
+ * @internal
  */
 #ifndef UCLN_NO_AUTO_CLEANUP
 #define UCLN_NO_AUTO_CLEANUP 1
 #endif
 
+#if 0
+#define CYGWINMSVC
+#endif
+
 /* Need platform.h when using CYGWINMSVC to get definitions above. Ignore everything else. */
 #ifndef CYGWINMSVC
 
@@ -87,7 +91,7 @@
  * For platforms that do not use platform.h and do not define this constant
  * in their platform-specific headers, std_string.h defaults
  * U_HAVE_STD_STRING to 1.
- * @draft ICU 4.2
+ * @internal
  */
 #ifndef U_HAVE_STD_STRING
 #define U_HAVE_STD_STRING 1
@@ -143,7 +147,7 @@
 #if defined(BYTE_ORDER) && defined(BIG_ENDIAN)
 #define U_IS_BIG_ENDIAN (BYTE_ORDER == BIG_ENDIAN)
 #else
-#define U_IS_BIG_ENDIAN 1
+#define U_IS_BIG_ENDIAN 0
 #endif
 
 /* 1 or 0 to enable or disable threads.  If undefined, default is: enable threads. */
@@ -151,11 +155,6 @@
 #define ICU_USE_THREADS 1
 #endif
 
-/* On strong memory model CPUs (e.g. x86 CPUs), we use a safe & quick double check lock. */
-#if defined(__GNUC__) && (defined(__i386__) || defined(__x86_64__))
-#define UMTX_STRONG_MEMORY_MODEL 1
-#endif
-
 #ifndef U_DEBUG
 #define U_DEBUG 0
 #endif
@@ -186,7 +185,7 @@
 
 /**
  * Whether to enable Dynamic loading in ICU
- * @draft ICU 4.4
+ * @internal
  */
 #ifndef U_ENABLE_DYLOAD
 #define U_ENABLE_DYLOAD 1
@@ -194,7 +193,7 @@
 
 /**
  * Whether to test Dynamic loading as an OS capabilty
- * @draft ICU 4.4
+ * @internal
  */
 #ifndef U_CHECK_DYLOAD
 #define U_CHECK_DYLOAD 1
@@ -298,7 +297,9 @@
 /** @{ Symbol import-export control                                              */
 /*===========================================================================*/
 
-#if 0
+#ifdef U_STATIC_IMPLEMENTATION
+#define U_EXPORT
+#elif 1
 #define U_EXPORT __attribute__((visibility("default")))
 #elif (defined(__SUNPRO_CC) && __SUNPRO_CC >= 0x550) \
    || (defined(__SUNPRO_C) && __SUNPRO_C >= 0x550) 
@@ -348,7 +349,7 @@
  * @internal
  */
 #ifndef U_HAVE_GCC_ATOMICS
-#define U_HAVE_GCC_ATOMICS 0
+#define U_HAVE_GCC_ATOMICS 1
 #endif
 
 /** @} */
@@ -392,7 +393,7 @@
 #if U_HAVE_LIB_SUFFIX
 # ifndef U_ICU_ENTRY_POINT_RENAME
 /* Renaming pattern:    u_strcpy_41_suffix */
-#  define U_ICU_ENTRY_POINT_RENAME(x)    x ## _ ## 44 ## 
+#  define U_ICU_ENTRY_POINT_RENAME(x)    x ## _ ## 48 ## 
 #  define U_DEF_ICUDATA_ENTRY_POINT(major, minor) icudt####major##minor##_dat
 
 # endif
